package PNI::Node::Perlop;

our $VERSION = '0.04';

1
__END__

=head1 NAME

PNI::Node::Perlop - PNI node collection

=head1 DESCRIPTION

It's a basic collection of PNI nodes implementing Perl operators.

=head1 SEE ALSO

L<PNI>

=cut

